@@ -236,8 +236,9 @@ class Configuration(optparse.OptionParser):
     """declarative configuration object"""
 
     options = {}         # configuration basis definition
+    extend = set()       # which dicts/lists should be extended
     load_option = 'load' # where to put the load option
-    extend = set()       # if dicts/lists should be extended
+    load_help = "load configuration from a file"
 
     def __init__(self, configuration_providers=configuration_providers, types=types, load=None, dump='--dump', **parser_args):
 
@@ -275,8 +276,9 @@ class Configuration(optparse.OptionParser):
         # add option(s) for configuration_providers
         if load:
             self.add_option(load,
-                            dest=self.load_option, action='append',
-                            help="load configuration from a file")
+                            dest=self.load_option,
+                            action='append',
+                            help=self.load_help)
 
         # add an option for dumping
         formats = self.formats()
@@ -432,8 +434,41 @@ class Configuration(optparse.OptionParser):
                 continue
             parser.add_option(*args, **kw)
 
+    def configuration_files(self, options, args):
+        """configuration files to read"""
+
+        configuration_files = getattr(options, self.load_option, args)
+        if not configuration_files:
+            configuration_files = []
+        if isinstance(configuration_files, basestring):
+            configuration_files = [configuration_files]
+        return configuration_files
+
+    def load_configuration_file(self, filename):
+        """load a configuration file"""
+        return self.deserialize(filename)
+
+    def read_configuration_files(self, options, args):
+        """deserialize configuration"""
+
+        configuration_files = self.configuration_files(options, args)
+        missing = [i for i in configuration_files
+                   if not os.path.exists(i)]
+        if missing:
+            self.error("Missing files: %s" % ', '.join(missing))
+        config = []
+        for f in configuration_files:
+            try:
+                loaded_config = self.load_configuration_file(f)
+                if loaded_config:
+                    config.append(loaded_config)
+            except BaseException, e:
+                parser.error(str(e))
+        return config
+
     def parse_args(self, *args, **kw):
 
+        # parse command line options
         self.parsed = dict()
         options, args = optparse.OptionParser.parse_args(self, *args, **kw)
 
@@ -442,23 +477,7 @@ class Configuration(optparse.OptionParser):
                            if key in self.option_dict and key in self.parsed])
 
         # deserialize configuration
-        configuration_files = getattr(options, self.load_option, args)
-        if not configuration_files:
-            configuration_files = []
-        if isinstance(configuration_files, basestring):
-            configuration_files = [configuration_files]
-        missing = [i for i in configuration_files
-                   if not os.path.exists(i)]
-        if missing:
-            self.error("Missing files: %s" % ', '.join(missing))
-        config = []
-        for f in configuration_files:
-            try:
-                loaded_config = self.deserialize(f)
-                if loaded_config:
-                    config.append(loaded_config)
-            except BaseException, e:
-                parser.error(str(e))
+        config = self.read_configuration_files(options, args)
         config.append(cli_config)
 
         missingvalues = None
